@@ -39,12 +39,10 @@
 #include <NvCtrlAttributes.h>
 
 #include "tv_banner.h"
-#include "ctkimage.h"
 
 #include "ctkdisplaydevice-tv.h"
 
 #include "ctkimagesliders.h"
-#include "ctkedid.h"
 #include "ctkconfig.h"
 #include "ctkhelp.h"
 #include "ctkscale.h"
@@ -138,12 +136,14 @@ GtkWidget* ctk_display_device_tv_new(NvCtrlAttributeHandle *handle,
 {
     GObject *object;
     CtkDisplayDeviceTv *ctk_display_device_tv;
-    GtkWidget *banner;
+    GtkWidget *image;
     GtkWidget *frame;
     GtkWidget *hbox;
     GtkWidget *label;
     GtkWidget *alignment;
-    GtkWidget *edid;
+    
+    guint8 *image_buffer = NULL;
+    const nv_image_t *img;    
     
     char *str;
     ReturnStatus ret;
@@ -159,11 +159,27 @@ GtkWidget* ctk_display_device_tv_new(NvCtrlAttributeHandle *handle,
     
     gtk_box_set_spacing(GTK_BOX(object), 10);
     
+    hbox = gtk_hbox_new(FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(object), hbox, FALSE, FALSE, 0);
+    
     /* banner */
 
-    banner = ctk_banner_image_new(&tv_banner_image);
-    gtk_box_pack_start(GTK_BOX(object), banner, FALSE, FALSE, 0);
+    frame = gtk_frame_new(NULL);
+    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
 
+    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+    
+    img = &tv_banner_image;
+    
+    image_buffer = decompress_image_data(img);
+    
+    image = gtk_image_new_from_pixbuf
+        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
+                                  FALSE, 8, img->width, img->height,
+                                  img->width * img->bytes_per_pixel,
+                                  free_decompressed_image, NULL));
+
+    gtk_container_add(GTK_CONTAINER(frame), image);
 
     /* NV_CTRL_STRING_TV_ENCODER_NAME */
     
@@ -286,18 +302,6 @@ GtkWidget* ctk_display_device_tv_new(NvCtrlAttributeHandle *handle,
                            "The Reset TV Hardware Defaults button restores "
                            "the TV settings to their default values.");
 
-    /* pack the EDID button */
-
-    edid = ctk_edid_new(handle, ctk_config, ctk_event,
-                        ctk_display_device_tv->reset_button,
-                        display_device_mask, name);
-    if (edid) {
-        gtk_box_pack_start(GTK_BOX(object), edid, FALSE, FALSE, 0);
-        ctk_display_device_tv->edid_available = TRUE;
-    } else {
-        ctk_display_device_tv->edid_available = FALSE;
-    }
-   
     /* finally, display the widget */
 
     gtk_widget_show_all(GTK_WIDGET(object));
@@ -632,13 +636,9 @@ GtkTextBuffer *ctk_display_device_tv_create_help(GtkTextTagTable *table,
     }
 
     if (ctk_display_device_tv->image_sliders) {
-        ret |= add_image_sliders_help
+        ret |= add_image_sharpening_help
             (CTK_IMAGE_SLIDERS(ctk_display_device_tv->image_sliders), b, &i);
     }
-
-    if (ctk_display_device_tv->edid_available) {
-        add_acquire_edid_help(b, &i);
-    }
     
     if (!ret) {
         ctk_help_para(b, &i, "There are no configurable options available "
