@@ -42,10 +42,6 @@
 #include <dlfcn.h>  /* To dynamically load libGL.so */
 #include <GL/glx.h> /* GLX #defines */
 
-#if defined(NV_BSD)
-static void *__libGL_handle = NULL;
-#endif
-
 /****
  *
  * Provides a way to communicate GLX settings.
@@ -129,28 +125,15 @@ NvCtrlInitGlxAttributes (NvCtrlAttributePrivateHandle *h)
     }
 
 
-#if defined(NV_BSD)
-    /*
-     * XXX In current versions of FreeBSD, static TLS data
-     * allocated for the initial dlopen() doesn't appear
-     * to be free()'d on dlclose(); this results in failures
-     * on subsequent attempts to open libGL.so.
-     */
-    if (__libGL_handle == NULL) {
-        __libGL_handle = dlopen("libGL.so.1", RTLD_LAZY);
-    }
-    glx->libGL = __libGL_handle;
-#else
     /* Link the libGL lib */
     glx->libGL = dlopen("libGL.so.1", RTLD_LAZY);
-#endif
     if ( glx->libGL == NULL ) {
         /* Silently fail */
         goto fail;
     }
 
     /* Make sure GLX is supported by the server */
-    glXQueryExtension = NV_DLSYM(glx->libGL, "glXQueryExtension");
+    glXQueryExtension = dlsym(glx->libGL, "glXQueryExtension");
     glx->dpy          = XOpenDisplay( XDisplayString(h->dpy) );
     if ( glx->dpy == NULL ) {
         goto fail;
@@ -161,41 +144,41 @@ NvCtrlInitGlxAttributes (NvCtrlAttributePrivateHandle *h)
 
 
     /* Resolve GLX functions */
-    glx->glGetString              = NV_DLSYM(glx->libGL,
+    glx->glGetString              = dlsym(glx->libGL,
                                           "glGetString");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXQueryExtensionsString = NV_DLSYM(glx->libGL,
+    glx->glXQueryExtensionsString = dlsym(glx->libGL,
                                           "glXQueryExtensionsString");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXQueryServerString     = NV_DLSYM(glx->libGL,
+    glx->glXQueryServerString     = dlsym(glx->libGL,
                                           "glXQueryServerString");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXGetClientString       = NV_DLSYM(glx->libGL,
+    glx->glXGetClientString       = dlsym(glx->libGL,
                                           "glXGetClientString");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXIsDirect              = NV_DLSYM(glx->libGL,
+    glx->glXIsDirect              = dlsym(glx->libGL,
                                           "glXIsDirect");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXMakeCurrent           = NV_DLSYM(glx->libGL,
+    glx->glXMakeCurrent           = dlsym(glx->libGL,
                                           "glXMakeCurrent");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXCreateContext         = NV_DLSYM(glx->libGL,
+    glx->glXCreateContext         = dlsym(glx->libGL,
                                           "glXCreateContext");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXDestroyContext        = NV_DLSYM(glx->libGL,
+    glx->glXDestroyContext        = dlsym(glx->libGL,
                                           "glXDestroyContext");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXChooseVisual          = NV_DLSYM(glx->libGL,
+    glx->glXChooseVisual          = dlsym(glx->libGL,
                                           "glXChooseVisual");
     if ((error = dlerror()) != NULL) goto fail;
 #ifdef GLX_VERSION_1_3
-    glx->glXGetFBConfigs          = NV_DLSYM(glx->libGL,
+    glx->glXGetFBConfigs          = dlsym(glx->libGL,
                                           "glXGetFBConfigs");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXGetFBConfigAttrib     = NV_DLSYM(glx->libGL,
+    glx->glXGetFBConfigAttrib     = dlsym(glx->libGL,
                                           "glXGetFBConfigAttrib");
     if ((error = dlerror()) != NULL) goto fail;
-    glx->glXGetVisualFromFBConfig = NV_DLSYM(glx->libGL,
+    glx->glXGetVisualFromFBConfig = dlsym(glx->libGL,
                                           "glXGetVisualFromFBConfig");
     if ((error = dlerror()) != NULL) goto fail;
 #endif /* GLX_VERSION_1_3 */
@@ -243,11 +226,9 @@ NvCtrlGlxAttributesClose (NvCtrlAttributePrivateHandle *h)
         XCloseDisplay( h->glx->dpy );
     }
 
-#if !defined(NV_BSD)
     if ( h->glx->libGL != NULL ) {
         dlclose( h->glx->libGL );
     }
-#endif
 
     free(h->glx);
     h->glx = NULL;
