@@ -67,14 +67,14 @@ set_rotation(NvCtrlAttributePrivateHandle *h, Rotation rotation)
     }
 
     /* Get current size & orientation */
-    sc = h->xrandr->XRRGetScreenInfo(h->xrandr->dpy, DefaultRootWindow(h->xrandr->dpy));
+    sc = h->xrandr->XRRGetScreenInfo(h->dpy, DefaultRootWindow(h->dpy));
     if ( !sc ) {
         return NvCtrlError;
     }
     cur_size = h->xrandr->XRRConfigCurrentConfiguration(sc, &cur_rotation);
 
-    status = h->xrandr->XRRSetScreenConfig (h->xrandr->dpy, sc,
-                                            DefaultRootWindow(h->xrandr->dpy),
+    status = h->xrandr->XRRSetScreenConfig (h->dpy, sc,
+                                            DefaultRootWindow(h->dpy),
                                             cur_size, rotation, CurrentTime);
     h->xrandr->XRRFreeScreenConfigInfo(sc);
 
@@ -129,52 +129,46 @@ NvCtrlInitXrandrAttributes (NvCtrlAttributePrivateHandle *h)
 
 
     /* Resolve XRandR functions */
-    xrandr->XRRQueryExtension = NV_DLSYM(xrandr->libXrandr,
+    xrandr->XRRQueryExtension = dlsym(xrandr->libXrandr,
                                       "XRRQueryExtension");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRSelectInput = NV_DLSYM(xrandr->libXrandr, "XRRSelectInput");
+    xrandr->XRRSelectInput = dlsym(xrandr->libXrandr, "XRRSelectInput");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRConfigCurrentConfiguration = NV_DLSYM(xrandr->libXrandr,
+    xrandr->XRRConfigCurrentConfiguration = dlsym(xrandr->libXrandr,
                                                   "XRRConfigCurrentConfiguration");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRGetScreenInfo = NV_DLSYM(xrandr->libXrandr,
+    xrandr->XRRGetScreenInfo = dlsym(xrandr->libXrandr,
                                      "XRRGetScreenInfo");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRConfigRotations = NV_DLSYM(xrandr->libXrandr, "XRRConfigRotations");
+    xrandr->XRRConfigRotations = dlsym(xrandr->libXrandr, "XRRConfigRotations");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRFreeScreenConfigInfo = NV_DLSYM(xrandr->libXrandr,
+    xrandr->XRRFreeScreenConfigInfo = dlsym(xrandr->libXrandr,
                                             "XRRFreeScreenConfigInfo");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRSetScreenConfig = NV_DLSYM(xrandr->libXrandr,
+    xrandr->XRRSetScreenConfig = dlsym(xrandr->libXrandr,
                                        "XRRSetScreenConfig");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRRotations = NV_DLSYM(xrandr->libXrandr, "XRRRotations");
+    xrandr->XRRRotations = dlsym(xrandr->libXrandr, "XRRRotations");
     if ((error = dlerror()) != NULL) goto fail;
 
-    xrandr->XRRSizes = NV_DLSYM(xrandr->libXrandr, "XRRSizes");
+    xrandr->XRRSizes = dlsym(xrandr->libXrandr, "XRRSizes");
     if ((error = dlerror()) != NULL) goto fail;
 
 
-    /* Duplicate the display connection */
-
-    xrandr->dpy = XOpenDisplay(XDisplayString(h->dpy));
-    if ( xrandr->dpy == NULL )
-        goto fail;
-
     /* Verify rotation is supported */
-    ret = xrandr->XRRQueryExtension(xrandr->dpy, &xrandr->event_base,
+    ret = xrandr->XRRQueryExtension(h->dpy, &xrandr->event_base,
                                     &xrandr->error_base);
     if ( !ret ) goto fail;
 
-    xrandr->rotations = xrandr->XRRRotations(xrandr->dpy, h->screen, &rotation);
-    sizes             = xrandr->XRRSizes(xrandr->dpy, h->screen, &(xrandr->nsizes));
+    xrandr->rotations = xrandr->XRRRotations(h->dpy, h->screen, &rotation);
+    sizes             = xrandr->XRRSizes(h->dpy, h->screen, &(xrandr->nsizes));
 
     /* Must support more than one rotation orientation */
     if ( (xrandr->rotations == 1) || (xrandr->rotations == 2) ||
@@ -184,7 +178,7 @@ NvCtrlInitXrandrAttributes (NvCtrlAttributePrivateHandle *h)
 
     
     /* Register to recieve XRandR events */
-    xrandr->XRRSelectInput(xrandr->dpy, DefaultRootWindow(xrandr->dpy),
+    xrandr->XRRSelectInput(h->dpy, DefaultRootWindow(h->dpy),
                            RRScreenChangeNotifyMask);   
 
     //    xrandr->rotations = 1;
@@ -198,9 +192,6 @@ NvCtrlInitXrandrAttributes (NvCtrlAttributePrivateHandle *h)
         nv_error_msg("libXrandr setup error : %s\n", error);
     }
     if ( xrandr != NULL ) {
-        if ( xrandr->dpy != NULL ) {
-            XCloseDisplay(xrandr->dpy);
-        }
         if ( xrandr->libXrandr != NULL ) {
             dlclose(xrandr->libXrandr);
         }
@@ -227,9 +218,6 @@ NvCtrlXrandrAttributesClose (NvCtrlAttributePrivateHandle *h)
         return;
     }
 
-    if ( h->xrandr->dpy ) {
-        XCloseDisplay(h->xrandr->dpy);
-    }
     if ( h->xrandr->libXrandr != NULL ) {
         dlclose( h->xrandr->libXrandr );
     }
@@ -279,7 +267,7 @@ NvCtrlXrandrGetAttribute (NvCtrlAttributePrivateHandle *h,
         break;
 
     case NV_CTRL_ATTR_XRANDR_ROTATION:
-        sc = h->xrandr->XRRGetScreenInfo(h->xrandr->dpy, DefaultRootWindow(h->xrandr->dpy));
+        sc = h->xrandr->XRRGetScreenInfo(h->dpy, DefaultRootWindow(h->dpy));
         h->xrandr->XRRConfigRotations(sc, &rotation);
         h->xrandr->XRRFreeScreenConfigInfo(sc);
 
